@@ -6,8 +6,6 @@
 
 #include "kcm_componentchooser.h"
 
-#include <QApplication>
-
 #include <KAboutData>
 #include <KBuildSycocaProgressDialog>
 #include <KLocalizedString>
@@ -89,7 +87,7 @@ void KcmComponentChooser::load()
 void KcmComponentChooser::save()
 {
     m_data->save();
-    KBuildSycocaProgressDialog::rebuildKSycoca(QApplication::activeWindow());
+    KBuildSycocaProgressDialog::rebuildKSycoca(nullptr);
 }
 
 bool KcmComponentChooser::isDefaults() const
