@@ -10,11 +10,13 @@
 #include <KAboutData>
 #include <KLocalizedString>
 #include <KPluginFactory>
+#include <KWindowSystem>
 
 #include <QDBusConnection>
 #include <QDBusMessage>
 
 #include "workspaceoptions_kdeglobalssettings.h"
+#include "workspaceoptions_kwinsettings.h"
 #include "workspaceoptions_plasmasettings.h"
 #include "workspaceoptionsdata.h"
 
@@ -24,8 +26,9 @@ KCMWorkspaceOptions::KCMWorkspaceOptions(QObject *parent, const QVariantList &ar
     : KQuickAddons::ManagedConfigModule(parent, args)
     , m_data(new WorkspaceOptionsData(this))
 {
-    qmlRegisterType<WorkspaceOptionsGlobalsSettings>();
-    qmlRegisterType<WorkspaceOptionsPlasmaSettings>();
+    qmlRegisterAnonymousType<WorkspaceOptionsGlobalsSettings>("org.kde.plasma.workspaceoptions.kcm", 0);
+    qmlRegisterAnonymousType<WorkspaceOptionsPlasmaSettings>("org.kde.plasma.workspaceoptions.kcm", 0);
+    qmlRegisterAnonymousType<WorkspaceOptionsKwinSettings>("org.kde.plasma.workspaceoptions.kcm", 0);
 
     KAboutData *about = new KAboutData(QStringLiteral("kcm_workspace"),
                                        i18n("General Behavior"),
@@ -49,6 +52,16 @@ WorkspaceOptionsPlasmaSettings *KCMWorkspaceOptions::plasmaSettings() const
     return m_data->workspaceOptionsPlasmaSettings();
 }
 
+WorkspaceOptionsKwinSettings *KCMWorkspaceOptions::kwinSettings() const
+{
+    return m_data->workspaceOptionsKwinSettings();
+}
+
+bool KCMWorkspaceOptions::isWayland() const
+{
+    return KWindowSystem::isPlatformWayland();
+}
+
 void KCMWorkspaceOptions::save()
 {
     ManagedConfigModule::save();
@@ -61,4 +74,5 @@ void KCMWorkspaceOptions::save()
     QDBusConnection::sessionBus().send(message);
 }
 
+#include "moc_workspaceoptions.cpp"
 #include "workspaceoptions.moc"
